@@ -3,9 +3,11 @@
 Curses Celery Event Viewer.
 
 """
+
 from celery.bin.celeryctl import celeryctl, Command as _Command
 
 from djcelery import __version__
+from djcelery.app import app
 from djcelery.management.base import CeleryCommand
 
 # Django hijacks the version output and prints its version before our
@@ -19,5 +21,6 @@ class Command(CeleryCommand):
     help = "celery control utility"
 
     def run_from_argv(self, argv):
-        util = celeryctl()
-        util.execute_from_commandline(argv[1:])
+        util = celeryctl(app=app)
+
+        util.execute_from_commandline(self.handle_default_options(argv)[1:])
